import json


class Theme:
    def __init__(self, path) -> None:
        self.path = path
        self.theme_json = {
            "CTk": {
                "fg_color": [
                "#ebebeb",
                "#1d1d1d"
                ]
            },
            "CTkToplevel": {
                "fg_color": [
                "gray92",
                "#1d1d1d"
                ]
            },
            "CTkFrame": {
                "corner_radius": 6,
                "border_width": 0,
                "fg_color": [
                "gray86",
                "#292929"
                ],
                "top_fg_color": [
                "gray81",
                "gray20"
                ],
                "border_color": [
                "gray65",
                "gray28"
                ]
            },
            "CTkButton": {
                "corner_radius": 6,
                "border_width": 0,
                "fg_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "border_color": [
                "#3E454A",
                "#949A9F"
                ],
                "text_color": [
                "#f7f7f7",
                "#f7f7f7"
                ],
                "text_color_disabled": [
                "gray74",
                "gray60"
                ]
            },
            "CTkLabel": {
                "corner_radius": 0,
                "fg_color": "transparent",
                "text_color": [
                "#313131",
                "#f7f7f7"
                ]
            },
            "CTkEntry": {
                "corner_radius": 6,
                "border_width": 2,
                "fg_color": [
                "#cfcfcf",
                "#323232"
                ],
                "border_color": [
                "#cfcfcf",
                "#323232"
                ],
                "text_color": [
                "#2a2a2a",
                "#f7f7f7"
                ],
                "placeholder_text_color": [
                "gray52",
                "gray62"
                ]
            },
            "CTkCheckBox": {
                "corner_radius": 6,
                "border_width": 3,
                "fg_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "border_color": [
                "#313131",
                "#949A9F"
                ],
                "hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "checkmark_color": [
                "#DCE4EE",
                "gray90"
                ],
                "text_color": [
                "gray10",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray60",
                "gray45"
                ]
            },
            "CTkSwitch": {
                "corner_radius": 1000,
                "border_width": 3,
                "button_length": 0,
                "fg_color": [
                "#939BA2",
                "#4A4D50"
                ],
                "progress_color": [
                "#ab5cff",
                "#35006f"
                ],
                "button_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "text_color": [
                "gray10",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray60",
                "gray45"
                ]
            },
            "CTkRadioButton": {
                "corner_radius": 1000,
                "border_width_checked": 6,
                "border_width_unchecked": 3,
                "fg_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "border_color": [
                "#313131",
                "#3f3f3f"
                ],
                "hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "text_color": [
                "gray10",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray60",
                "gray45"
                ]
            },
            "CTkProgressBar": {
                "corner_radius": 1000,
                "border_width": 0,
                "fg_color": [
                "#ab5cff",
                "#35006f"
                ],
                "progress_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "border_color": [
                "gray",
                "gray"
                ]
            },
            "CTkSlider": {
                "corner_radius": 1000,
                "button_corner_radius": 1000,
                "border_width": 6,
                "button_length": 0,
                "fg_color": [
                "#ab5cff",
                "#35006f"
                ],
                "progress_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ]
            },
            "CTkOptionMenu": {
                "corner_radius": 6,
                "fg_color": [
                "#ab5cff",
                "#35006f"
                ],
                "button_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "text_color": [
                "#DCE4EE",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray74",
                "gray60"
                ]
            },
            "CTkComboBox": {
                "corner_radius": 6,
                "border_width": 2,
                "fg_color": [
                "#ab5cff",
                "#35006f"
                ],
                "border_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "button_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "text_color": [
                "#f7f7f7",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray50",
                "gray45"
                ]
            },
            "CTkScrollbar": {
                "corner_radius": 1000,
                "border_spacing": 4,
                "fg_color": "transparent",
                "button_color": [
                "#cecece",
                "#636363"
                ],
                "button_hover_color": [
                "gray40",
                "gray53"
                ]
            },
            "CTkSegmentedButton": {
                "corner_radius": 6,
                "border_width": 2,
                "fg_color": [
                "#ab5cff",
                "#35006f"
                ],
                "selected_color": [
                "#5f00c7",
                "#5f00c7"
                ],
                "selected_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "unselected_color": [
                "#ab5cff",
                "#35006f"
                ],
                "unselected_hover_color": [
                "#7d03ff",
                "#7d03ff"
                ],
                "text_color": [
                "#DCE4EE",
                "#DCE4EE"
                ],
                "text_color_disabled": [
                "gray74",
                "gray60"
                ]
            },
            "CTkTextbox": {
                "corner_radius": 6,
                "border_width": 0,
                "fg_color": [
                "#dbdbdb",
                "#2a2a2a"
                ],
                "border_color": [
                "#979DA2",
                "#565B5E"
                ],
                "text_color": [
                "gray10",
                "#DCE4EE"
                ],
                "scrollbar_button_color": [
                "gray55",
                "gray41"
                ],
                "scrollbar_button_hover_color": [
                "gray40",
                "gray53"
                ]
            },
            "CTkScrollableFrame": {
                "label_fg_color": [
                "gray78",
                "gray23"
                ]
            },
            "DropdownMenu": {
                "fg_color": [
                "gray90",
                "gray20"
                ],
                "hover_color": [
                "gray75",
                "gray28"
                ],
                "text_color": [
                "gray10",
                "gray90"
                ]
            },
            "CTkFont": {
                "macOS": {
                "family": "SF Display",
                "size": 13,
                "weight": "normal"
                },
                "Windows": {
                "family": "Roboto",
                "size": 13,
                "weight": "normal"
                },
                "Linux": {
                "family": "Roboto",
                "size": 13,
                "weight": "normal"
                }
            }
        }
    def get_theme(self):
        with open(self.path + "/theme.json", "w") as file:
            json.dump(self.theme_json, file, indent=4)
        return self.path + "/theme.json"
